@@ -8,9 +8,9 @@ templates_path = ['_templates']
 source_suffix = '.rst'
 master_doc = 'index'
 project = u'django-registration'
-copyright = u'2007-2015, James Bennett'
-version = '2.1'
-release = '2.1.2'
+copyright = u'2007-2016, James Bennett'
+version = '2.2'
+release = '2.2'
 exclude_trees = ['_build']
 pygments_style = 'sphinx'
 html_static_path = ['_static']
