@@ -7,7 +7,7 @@ setting, which should only occur if you are using the model-based
 activation workflow.
 
 """
-
+from django.apps import apps
 from django.contrib import admin
 from django.contrib.sites.shortcuts import get_current_site
 from django.utils.translation import ugettext_lazy as _
@@ -15,7 +15,6 @@ from django.utils.translation import ugettext_lazy as _
 from registration.models import RegistrationProfile
 
 
-@admin.register(RegistrationProfile)
 class RegistrationAdmin(admin.ModelAdmin):
     actions = ['activate_users', 'resend_activation_email']
     list_display = ('user', 'activation_key_expired')
@@ -30,7 +29,7 @@ class RegistrationAdmin(admin.ModelAdmin):
         """
         for profile in queryset:
             RegistrationProfile.objects.activate_user(profile.activation_key)
-    activate_users.short_description = _("Activate users")
+    activate_users.short_description = _(u"Activate users")
 
     def resend_activation_email(self, request, queryset):
         """
@@ -47,4 +46,8 @@ class RegistrationAdmin(admin.ModelAdmin):
                 profile.send_activation_email(
                     get_current_site(request)
                 )
-    resend_activation_email.short_description = _("Re-send activation emails")
+    resend_activation_email.short_description = _(u"Re-send activation emails")
+
+
+if apps.is_installed('registration'):
+    admin.site.register(RegistrationProfile, RegistrationAdmin)
