@@ -9,8 +9,10 @@ import time
 from django.conf import settings
 from django.core import signing
 from django.core.urlresolvers import reverse
+from django.http import HttpRequest
 from django.test import modify_settings, override_settings
 
+from .. import signals
 from registration.backends.hmac.views import REGISTRATION_SALT
 
 from .base import ActivationTestCase
@@ -34,17 +36,19 @@ class HMACViewTests(ActivationTestCase):
         )
 
         activation_key = signing.dumps(
-            obj=self.valid_data['username'],
+            obj=self.valid_data[self.user_model.USERNAME_FIELD],
             salt=REGISTRATION_SALT
         )
 
-        resp = self.client.get(
-            reverse(
-                'registration_activate',
-                args=(),
-                kwargs={'activation_key': activation_key}
+        with self.assertSignalSent(signals.user_activated):
+            resp = self.client.get(
+                reverse(
+                    'registration_activate',
+                    args=(),
+                    kwargs={'activation_key': activation_key}
+                )
             )
-        )
+
         self.assertRedirects(resp, reverse('registration_activation_complete'))
 
     def test_repeat_activation(self):
@@ -59,27 +63,29 @@ class HMACViewTests(ActivationTestCase):
         )
 
         activation_key = signing.dumps(
-            obj=self.valid_data['username'],
+            obj=self.valid_data[self.user_model.USERNAME_FIELD],
             salt=REGISTRATION_SALT
         )
 
-        resp = self.client.get(
-            reverse(
-                'registration_activate',
-                args=(),
-                kwargs={'activation_key': activation_key}
+        with self.assertSignalSent(signals.user_activated):
+            resp = self.client.get(
+                reverse(
+                    'registration_activate',
+                    args=(),
+                    kwargs={'activation_key': activation_key}
+                )
             )
-        )
         # First activation redirects to success.
         self.assertRedirects(resp, reverse('registration_activation_complete'))
 
-        resp = self.client.get(
-            reverse(
-                'registration_activate',
-                args=(),
-                kwargs={'activation_key': activation_key}
+        with self.assertSignalNotSent(signals.user_activated):
+            resp = self.client.get(
+                reverse(
+                    'registration_activate',
+                    args=(),
+                    kwargs={'activation_key': activation_key}
+                )
             )
-        )
 
         # Second activation fails.
         self.assertEqual(200, resp.status_code)
@@ -120,23 +126,24 @@ class HMACViewTests(ActivationTestCase):
             joined_timestamp - (settings.ACCOUNT_ACTIVATION_DAYS + 1) * 86400
         )
         _old_time = time.time
-        time.time = lambda: expired_timestamp
 
         try:
+            time.time = lambda: expired_timestamp
             activation_key = signing.dumps(
-                obj=self.valid_data['username'],
+                obj=self.valid_data[self.user_model.USERNAME_FIELD],
                 salt=REGISTRATION_SALT
             )
         finally:
             time.time = _old_time
 
-        resp = self.client.get(
-            reverse(
-                'registration_activate',
-                args=(),
-                kwargs={'activation_key': activation_key}
+        with self.assertSignalNotSent(signals.user_activated):
+            resp = self.client.get(
+                reverse(
+                    'registration_activate',
+                    args=(),
+                    kwargs={'activation_key': activation_key}
+                )
             )
-        )
 
         self.assertEqual(200, resp.status_code)
         self.assertTemplateUsed(resp, 'registration/activate.html')
@@ -152,13 +159,43 @@ class HMACViewTests(ActivationTestCase):
             salt=REGISTRATION_SALT
         )
 
-        resp = self.client.get(
-            reverse(
-                'registration_activate',
-                args=(),
-                kwargs={'activation_key': activation_key}
+        with self.assertSignalNotSent(signals.user_activated):
+            resp = self.client.get(
+                reverse(
+                    'registration_activate',
+                    args=(),
+                    kwargs={'activation_key': activation_key}
+                )
             )
-        )
 
         self.assertEqual(200, resp.status_code)
         self.assertTemplateUsed(resp, 'registration/activate.html')
+
+    def test_activation_signal(self):
+        self.client.post(
+            reverse('registration_register'),
+            data=self.valid_data
+        )
+
+        activation_key = signing.dumps(
+            obj=self.valid_data[self.user_model.USERNAME_FIELD],
+            salt=REGISTRATION_SALT
+        )
+
+        with self.assertSignalSent(signals.user_activated,
+                                   required_kwargs=['user', 'request']) as cm:
+            self.client.get(
+                reverse(
+                    'registration_activate',
+                    args=(),
+                    kwargs={'activation_key': activation_key}
+                )
+            )
+            self.assertEqual(
+                getattr(cm.received_kwargs['user'],
+                        self.user_model.USERNAME_FIELD),
+                self.valid_data[self.user_model.USERNAME_FIELD]
+            )
+            self.assertTrue(
+                isinstance(cm.received_kwargs['request'], HttpRequest)
+            )
